@@ -1,7 +1,3 @@
-# coding: utf-8
-
-from __future__ import unicode_literals
-
 import pytest
 
 
@@ -12,12 +8,21 @@ import pytest
 def test_ca_tokenizer_handles_abbr(ca_tokenizer, text, lemma):
     tokens = ca_tokenizer(text)
     assert len(tokens) == 1
-    assert tokens[0].lemma_ == lemma
 
 
 def test_ca_tokenizer_handles_exc_in_text(ca_tokenizer):
-    text = "La Núria i el Pere han vingut aprox. a les 7 de la tarda."
-    tokens = ca_tokenizer(text)
-    assert len(tokens) == 15
-    assert tokens[7].text == "aprox."
-    assert tokens[7].lemma_ == "aproximadament"
+    text = "La Dra. Puig viu a la pl. dels Til·lers."
+    doc = ca_tokenizer(text)
+    assert [t.text for t in doc] == [
+        "La",
+        "Dra.",
+        "Puig",
+        "viu",
+        "a",
+        "la",
+        "pl.",
+        "d",
+        "els",
+        "Til·lers",
+        ".",
+    ]
